@@ -685,7 +685,6 @@ cal.J.default <- function(data, ...) {
 #'
 #' @param data \code{data.frame} or \code{matrix}. The nematode abundance table where rows represent samples and columns represent nematode genera.
 #' Each element indicates the count of a specific nematode genus in the corresponding sample. Row names must be sample names, and column names must be nematode genus names.
-#' @param total.abundance \code{data.frame}. A data frame with sample names as row names and a single column containing the total nematode abundance for each sample.
 #' @param method The method used to calculate the Species Richness Index. Default is \code{"Margalef"}.
 #' Supported methods are \code{"Margalef"} and \code{"Menhinick"}. Only one method can be specified.
 #'   \itemize{
@@ -706,36 +705,26 @@ cal.J.default <- function(data, ...) {
 #'   Pratylenchus = c(8, 12, 10),
 #'   row.names = c("A", "B", "C")
 #' )
-#' abundance <- data.frame(
-#'   abundance = c(100, 150, 120),
-#'   row.names = c("A", "B", "C")
-#' )
-#' cal.SRI(data = df, total.abundance = abundance, method = "Margalef")
+#' cal.SRI(data = df, method = "Margalef")
 #' @export
-cal.SRI <- function(data, total.abundance, method = "Margalef", ...) {
+cal.SRI <- function(data, method = "Margalef", ...) {
   UseMethod("cal.SRI")
 }
 
 #' @rdname cal.SRI
 #' @method cal.SRI data.frame
 #' @exportS3Method Nematode::cal.SRI
-cal.SRI.data.frame <- function(data, total.abundance, method = "Margalef", ...) {
+cal.SRI.data.frame <- function(data, method = "Margalef", ...) {
   if (is.null(rownames(data)) || is.null(colnames(data))) {
     stop("Data must have row names and column names")
   }
   if (!all(sapply(data, is.numeric))) {
     stop("The data contains non-numeric characters!")
   }
-  if (!all(row.names(data) %in% row.names(total.abundance))) {
-    stop("Please provide the total.abundance information for all samples!")
-  }
-  if (!all(sapply(total.abundance, is.numeric))) {
-    stop("The total.abundance contains non-numeric characters!")
-  }
   if (!method %in% c("Margalef", "Menhinick")) {
     stop("Invalid method. Choose from 'Margalef' or 'Menhinick'.")
   }
-  abundance <- data.frame(Sample.ID = rownames(total.abundance), abundance = total.abundance[, 1])
+  abundance <- data.frame(Sample.ID = rownames(data), abundance = rowSums(data, na.rm = T))
   N <- num_species(data)
   N_abundance <- merge(N, abundance, by = "Sample.ID")
   if (method == "Margalef") {
@@ -755,23 +744,17 @@ cal.SRI.data.frame <- function(data, total.abundance, method = "Margalef", ...)
 #' @rdname cal.SRI
 #' @method cal.SRI matrix
 #' @exportS3Method Nematode::cal.SRI
-cal.SRI.matrix <- function(data, total.abundance, method = "Margalef", ...) {
+cal.SRI.matrix <- function(data, method = "Margalef", ...) {
   if (is.null(rownames(data)) || is.null(colnames(data))) {
     stop("Data must have row names and column names")
   }
   if (!all(is.numeric(data))) {
     stop("The data contains non-numeric characters!")
   }
-  if (!all(row.names(data) %in% row.names(total.abundance))) {
-    stop("Please provide the total.abundance information for all samples!")
-  }
-  if (!all(sapply(total.abundance, is.numeric))) {
-    stop("The total.abundance contains non-numeric characters!")
-  }
   if (!method %in% c("Margalef", "Menhinick")) {
     stop("Invalid method. Choose from 'Margalef' or 'Menhinick'.")
   }
-  abundance <- data.frame(Sample.ID = rownames(total.abundance), abundance = total.abundance[, 1])
+  abundance <- data.frame(Sample.ID = rownames(data), abundance = rowSums(data, na.rm = T))
   N <- num_species(data)
   N_abundance <- merge(N, abundance, by = "Sample.ID")
   if (method == "Margalef") {
@@ -791,7 +774,7 @@ cal.SRI.matrix <- function(data, total.abundance, method = "Margalef", ...) {
 #' @rdname cal.SRI
 #' @method cal.SRI default
 #' @exportS3Method Nematode::cal.SRI
-cal.SRI.default <- function(data, total.abundance, method = "Margalef", ...) {
+cal.SRI.default <- function(data, method = "Margalef", ...) {
   # Error for unsupported input types
   stop("Unsupported input type: ", paste(class(data), collapse = "/"), call. = FALSE)
 }
@@ -1747,8 +1730,6 @@ cal.BI.default <- function(data, ...) {
 #'     \item "SI" - Structure Index
 #'   }
 #'   Additionally, specifying \code{All} will calculate all supported indices. \code{All} is the default value.
-#' @param total.abundance A data.frame containing abundance information for the samples. It must match the row names of the input data.
-#'     Default is \code{NULL}. This parameter is required when \code{indices} contains \code{SRI}.
 #' @param method The method to use for calculating the Species Richness Index. Default is \code{NULL}, which uses the default method \code{Margalef}. Options include:
 #'   \itemize{
 #'     \item \code{"Margalef"}: Margalef's Richness Index, calculated as \eqn{(S - 1) / \ln(N)}.
@@ -1766,20 +1747,16 @@ cal.BI.default <- function(data, ...) {
 #'   Pratylenchus = c(8, 12, 10),
 #'   row.names = c("A", "B", "C")
 #' )
-#' abundance <- data.frame(
-#'   abundance = c(100, 150, 120),
-#'   row.names = c("A", "B", "C")
-#' )
-#' Ecological.Indices(data = df, indices = "All", total.abundance = abundance, method = "Menhinick")
+#' Ecological.Indices(data = df, indices = "All", method = "Menhinick")
 #' @export
-Ecological.Indices <- function(data, indices = "All", total.abundance = NULL, method = NULL, ...) {
+Ecological.Indices <- function(data, indices = "All", method = NULL, ...) {
   UseMethod("Ecological.Indices")
 }
 
 #' @rdname Ecological.Indices
 #' @method Ecological.Indices data.frame
 #' @exportS3Method Nematode::Ecological.Indices
-Ecological.Indices.data.frame <- function(data, indices = "All", total.abundance = NULL, method = NULL, ...) {
+Ecological.Indices.data.frame <- function(data, indices = "All", method = NULL, ...) {
   if (is.null(rownames(data)) || is.null(colnames(data))) {
     stop("Data must have row names and column names")
   }
@@ -1807,14 +1784,11 @@ Ecological.Indices.data.frame <- function(data, indices = "All", total.abundance
   result_list <- list()
 
   if ("SRI" %in% indices) {
-    if (is.null(total.abundance)) {
-      stop("Error: 'total.abundance' is required when 'SRI' is specified in 'indices'.")
-    }
     if (is.null(method)) {
       warning("Using default method 'Margalef' for 'SRI'. To use 'Menhinick' method, specify method = 'Menhinick'.")
       method <- "Margalef"
     }
-    result_list[["SRI"]] <- cal.SRI(data = data, total.abundance = total.abundance, method = method)
+    result_list[["SRI"]] <- cal.SRI(data = data, method = method)
     indices <- setdiff(indices, "SRI")
   }
 
@@ -1836,7 +1810,7 @@ Ecological.Indices.data.frame <- function(data, indices = "All", total.abundance
 #' @rdname Ecological.Indices
 #' @method Ecological.Indices matrix
 #' @exportS3Method Nematode::Ecological.Indices
-Ecological.Indices.matrix <- function(data, indices = "All", total.abundance = NULL, method = NULL, ...) {
+Ecological.Indices.matrix <- function(data, indices = "All", method = NULL, ...) {
   if (is.null(rownames(data)) || is.null(colnames(data))) {
     stop("Data must have row names and column names")
   }
@@ -1864,14 +1838,11 @@ Ecological.Indices.matrix <- function(data, indices = "All", total.abundance = N
   result_list <- list()
 
   if ("SRI" %in% indices) {
-    if (is.null(total.abundance)) {
-      stop("Error: 'total.abundance' is required when 'SRI' is specified in 'indices'.")
-    }
     if (is.null(method)) {
       warning("Using default method 'Margalef' for 'SRI'. To use 'Menhinick' method, specify method = 'Menhinick'.")
       method <- "Margalef"
     }
-    result_list[["SRI"]] <- cal.SRI(data = data, total.abundance = total.abundance, method = method)
+    result_list[["SRI"]] <- cal.SRI(data = data, method = method)
     indices <- setdiff(indices, "SRI")
   }
 
@@ -1893,7 +1864,7 @@ Ecological.Indices.matrix <- function(data, indices = "All", total.abundance = N
 #' @rdname Ecological.Indices
 #' @method Ecological.Indices default
 #' @exportS3Method Nematode::Ecological.Indices
-Ecological.Indices.default <- function(data, indices = "All", total.abundance = NULL, method = NULL, ...) {
+Ecological.Indices.default <- function(data, indices = "All", method = NULL, ...) {
   # Error for unsupported input types
   stop("Unsupported input type: ", paste(class(data), collapse = "/"), call. = FALSE)
 }
